pub struct rustls_root_cert_store { /* private fields */ }
Implementations

Create a rustls_root_cert_store. Caller owns the memory and must eventually call rustls_root_cert_store_free. The store starts out empty. Caller must add root certificates with rustls_root_cert_store_add_pem. https://docs.rs/rustls/0.20.0/rustls/struct.RootCertStore.html#method.empty

Add one or more certificates to the root cert store using PEM encoded data.

When strict is true an error will return a CertificateParseError result. So will an attempt to parse data that has zero certificates.

When strict is false, unparseable root certificates will be ignored. This may be useful on systems that have syntactically invalid root certificates.

Free a rustls_root_cert_store previously returned from rustls_root_cert_store_builder_build. Calling with NULL is fine. Must not be called twice with the same value.