Module log

Module log 

Structs

rustls_log_params
Parameter structure passed to a rustls_log_callback.

Functions

rustls_log_level_str
Return a rustls_str containing the stringified version of a log level.

Type Aliases

rustls_log_callback
A callback that is invoked for messages logged by rustls.
rustls_log_level
Numeric representation of a log level.