#[repr(C)]
pub struct rustls_str<'a> { pub data: *const c_char, pub len: size_t, /* private fields */ }
A read-only view on a Rust &str. The contents are guaranteed to be valid UTF-8. As an additional guarantee on top of Rust’s normal UTF-8 guarantee, a rustls_str is guaranteed not to contain internal NUL bytes, so it is safe to interpolate into a C string or compare using strncmp. Keep in mind that it is not NUL-terminated.

The memory exposed is available as specified by the function using this in its signature. For instance, when this is a parameter to a callback, the lifetime will usually be the duration of the callback. Functions that receive one of these must not dereference the data pointer beyond the allowed lifetime.

Fields

data: *const c_charlen: size_t

Implementations

rustls_str represents a string that can be passed to C code. The string should not have any internal null bytes and is not null terminated. C code should not create rustls_str objects, they should only be created in Rust code.