Structs
- rustls_
client_ hello - The TLS Client Hello information provided to a ClientHelloCallback function.
- rustls_
server_ config - A server config that is done being constructed and is now read-only.
- rustls_
server_ config_ builder - A server config being constructed.
Functions
- rustls_
client_ hello_ select_ certified_ key - Select a
rustls_certified_keyfrom the list that matches the cryptographic parameters of a TLS client hello. - rustls_
server_ connection_ get_ server_ name - Returns a
rustls_strreference to the server name sent by the client in a server name indication (SNI) extension.
Type Aliases
- rustls_
client_ hello_ callback - Prototype of a callback that can be installed by the application at the
rustls_server_config. - rustls_
client_ hello_ userdata - Any context information the callback will receive when invoked.