pub struct rustls_client_hello<'a> { /* private fields */ }Expand description
The TLS Client Hello information provided to a ClientHelloCallback function.
server_name is the value of the ServerNameIndication extension provided
by the client. If the client did not send an SNI, the length of this
rustls_string will be 0.
signature_schemes carries the values supplied by the client or, if the
client did not send this TLS extension, the default schemes in the rustls library. See:
https://docs.rs/rustls/latest/rustls/enum.SignatureScheme.html.
named_groups carries the values of the named_groups extension sent by the
client. If the client did not send a named_groups extension, the length of
this rustls_slice_u16 will be 0. The meaning of this extension differ
based on TLS version. See the Rustls documentation for more information:
https://rustls.dev/docs/server/struct.ClientHello.html#method.named_groups
alpn carries the list of ALPN protocol names that the client proposed to
the server. Again, the length of this list will be 0 if none were supplied.
All this data, when passed to a callback function, is only accessible during the call and may not be modified. Users of this API must copy any values that they want to access when the callback returned.
EXPERIMENTAL: this feature of rustls-ffi is likely to change in the future, as the rustls library is re-evaluating their current approach to client hello handling.