#[unsafe(no_mangle)]pub extern "C" fn rustls_version() -> rustls_str<'static>Expand description
Returns a static string containing the rustls-ffi version as well as the rustls version. The string is alive for the lifetime of the program and does not need to be freed.