Function rustls_ffi::cipher::rustls_default_ciphersuites_get_entry
source · [−]#[no_mangle]
pub extern "C" fn rustls_default_ciphersuites_get_entry(
i: size_t
) -> *const rustls_supported_ciphersuiteExpand description
Get a pointer to a member of rustls’ list of supported cipher suites. This will return non-NULL for i < rustls_default_ciphersuites_len(). The returned pointer is valid for the lifetime of the program and may be used directly when building a ClientConfig or ServerConfig.