Struct rustls_ffi::client::rustls_client_config
source · [−]pub struct rustls_client_config { /* private fields */ }Expand description
A client config that is done being constructed and is now read-only.
Under the hood, this object corresponds to an Arc
Implementations
sourceimpl rustls_client_config
impl rustls_client_config
source#[no_mangle]pub extern "C" fn rustls_client_config_free(
config: *const rustls_client_config
)
#[no_mangle]pub extern "C" fn rustls_client_config_free(
config: *const rustls_client_config
)
“Free” a rustls_client_config previously returned from rustls_client_config_builder_build. Since rustls_client_config is actually an atomically reference-counted pointer, extant client connections may still hold an internal reference to the Rust object. However, C code must consider this pointer unusable after “free“ing it. Calling with NULL is fine. Must not be called twice with the same value.
source#[no_mangle]pub extern "C" fn rustls_client_connection_new(
config: *const rustls_client_config,
hostname: *const c_char,
conn_out: *mut *mut rustls_connection
) -> rustls_result
#[no_mangle]pub extern "C" fn rustls_client_connection_new(
config: *const rustls_client_config,
hostname: *const c_char,
conn_out: *mut *mut rustls_connection
) -> rustls_result
Create a new rustls_connection containing a client connection and return
it in the output parameter out. If this returns an error code, the
memory pointed to by conn_out remains unchanged. If this returns a
non-error, the memory pointed to by conn_out is modified to point at a
valid rustls_connection. The caller now owns the rustls_connection and must
call rustls_connection_free when done with it.