Struct rustls_ffi::rslice::rustls_slice_slice_bytes
source · [−]pub struct rustls_slice_slice_bytes<'a> { /* private fields */ }Expand description
A read-only view of a slice of Rust byte slices.
This is used to pass data from rustls-ffi to callback functions provided
by the user of the API. Because Vec and slice are not #[repr(C)], we
provide access via a pointer to an opaque struct and an accessor method
that acts on that struct to get entries of type rustls_slice_bytes.
Internally, the pointee is a &[&[u8]].
The memory exposed is available as specified by the function using this in its signature. For instance, when this is a parameter to a callback, the lifetime will usually be the duration of the callback. Functions that receive one of these must not call its methods beyond the allowed lifetime.