Struct rustls_ffi::rustls_io_result
source · [−]#[repr(transparent)]pub struct rustls_io_result(pub c_int);Expand description
A return value for a function that may return either success (0) or a non-zero value representing an error. The values should match socket error numbers for your operating system - for example, the integers for ETIMEDOUT, EAGAIN, or similar.
Tuple Fields
0: c_intAuto Trait Implementations
impl RefUnwindSafe for rustls_io_result
impl Send for rustls_io_result
impl Sync for rustls_io_result
impl Unpin for rustls_io_result
impl UnwindSafe for rustls_io_result